pipesnake\.pipe package
=======================

Submodules
----------

pipesnake\.pipe\.parallel module
--------------------------------

.. automodule:: pipesnake.pipe.parallel
    :members:
    :undoc-members:
    :show-inheritance:

pipesnake\.pipe\.series module
------------------------------

.. automodule:: pipesnake.pipe.series
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pipesnake.pipe
    :members:
    :undoc-members:
    :show-inheritance:
